@@ -12,7 +12,11 @@ pub type Id = (JsWord, SyntaxContext);
 
 impl<'a> Ident<'a> {
   pub fn to_id(&self) -> Id {
-    (self.inner.sym.clone(), self.inner.span.ctxt())
+    (self.sym().clone(), self.ctxt())
+  }
+
+  pub fn ctxt(&self) -> SyntaxContext {
+    self.inner.span.ctxt
   }
 }
 
@@ -20,4 +24,8 @@ impl<'a> BindingIdent<'a> {
   pub fn to_id(&self) -> Id {
     self.id.to_id()
   }
+
+  pub fn ctxt(&self) -> SyntaxContext {
+    self.id.ctxt()
+  }
 }
